==> spip_4.0.4.orig.tar.xz: plugins-dist/mots/lang/adminmots_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/adminmots?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_associer' => 'Associato',
	'bouton_dissocier' => 'Dissociato',
	'bouton_fusionner' => 'Unisci',

	// E
	'erreur_admin_mot_action_inconnue' => 'Cosa vuoi fare?',
	'erreur_mot_cle_deja' => 'Impossibile: questa è già la parola chiave su cui ti trovi.',
	'erreur_selection_id' => 'Seleziona una parola chiave o inserisci il suo ID nel campo di input',

	// I
	'icone_administrer_mot' => 'Amministrazione avanzata',

	// L
	'label_associer_objets_mot' => '<b>Associa</b> questa parola agli oggetti che hanno già la parola',
	'label_confirm_fusion' => 'Questa operazione non può essere annullata.<br />
<strong>La parola chiave attuale #@id_mot@ verrà eliminata</strong> e i seguenti link verranno trasferiti alla parola #@id_mot_new@ : ',
	'label_confirm_fusion_check' => 'Seleziona per confermare la fusione della parola chiave #@id_mot@ nella parola chiave #@id_mot_new@',
	'label_dissocier_objets_mot' => '<b>Dissocia</b> questa parola agli oggetti che hanno già la parola',
	'label_fusionner_mot' => '<b>Unisci</b> con la parola chiave',
	'label_mot_1_enfant' => 'Figlio:',
	'label_mot_nb_enfants' => 'Figli:',
	'label_mot_parent' => 'Padre:',

	// P
	'placeholder_id_mot' => 'oppure #ID_MOT',
	'placeholder_select' => 'Selezionare...',

	// R
	'result_associer_nb' => 'sono stati associati a questa parola chiave',
	'result_associer_ras' => 'Niente da fare: tutti gli oggetti hanno già questa parola chiave',
	'result_cancel_ok' => 'L’ultima operazione è stata annullata.',
	'result_dissocier_nb' => 'sono stati dissociati da questa parola chiave',
	'result_dissocier_ras' => 'Niente da fare: nessun oggetto rilevante è associato a questa parola chiave',
	'result_fusionner_ok' => 'Ora puoi cancellare questa parola: tutti i link sono stati trasferiti all’altra @mot@.',

	// T
	'titre_formulaire_administrer_mot' => 'Amministra la parola'
);

==> spip_4.4.5+dfsg.orig.tar.xz: plugins-dist/mots/lang/adminmots_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/adminmots?lang_cible=it
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_associer' => 'Associato',
	'bouton_dissocier' => 'Dissociato',
	'bouton_fusionner' => 'Unisci',

	// E
	'erreur_admin_mot_action_inconnue' => 'Cosa vuoi fare?',
	'erreur_mot_cle_deja' => 'Impossibile: questa è già la parola chiave su cui ti trovi.',
	'erreur_selection_id' => 'Seleziona una parola chiave o inserisci il suo ID nel campo di input',

	// I
	'icone_administrer_mot' => 'Amministrazione avanzata',

	// L
	'label_associer_objets_mot' => '<b>Associa</b> questa parola agli oggetti che hanno già la parola',
	'label_confirm_fusion' => 'Questa operazione non può essere annullata.<br />
<strong>La parola chiave attuale #@id_mot@ verrà eliminata</strong> e i seguenti link verranno trasferiti alla parola #@id_mot_new@ : ',
	'label_confirm_fusion_check' => 'Seleziona per confermare la fusione della parola chiave #@id_mot@ nella parola chiave #@id_mot_new@',
	'label_dissocier_objets_mot' => '<b>Dissocia</b> questa parola agli oggetti che hanno già la parola',
	'label_fusionner_mot' => '<b>Unisci</b> con la parola chiave',
	'label_mot_1_enfant' => 'Figlio:',
	'label_mot_nb_enfants' => 'Figli:',
	'label_mot_parent' => 'Padre:',

	// P
	'placeholder_id_mot' => 'oppure #ID_MOT',
	'placeholder_select' => 'Selezionare...',

	// R
	'result_associer_nb' => 'sono stati associati a questa parola chiave',
	'result_associer_ras' => 'Niente da fare: tutti gli oggetti hanno già questa parola chiave',
	'result_cancel_ok' => 'L’ultima operazione è stata annullata.',
	'result_dissocier_nb' => 'sono stati dissociati da questa parola chiave',
	'result_dissocier_ras' => 'Niente da fare: nessun oggetto rilevante è associato a questa parola chiave',
	'result_fusionner_ok' => 'Ora puoi cancellare questa parola: tutti i link sono stati trasferiti all’altra @mot@.',

	// T
	'titre_formulaire_administrer_mot' => 'Amministra la parola',
];
